Function wasi_experimental_http::request [−][src]
pub fn request(req: Request<Option<Bytes>>) -> Result<Response, Error>
Send an HTTP request.
The function returns a Response object, that includes the status,
as well as methods to access the headers and the body.